@@ -1,6 +1,6 @@
 package com.genymobile.scrcpy.wrappers;
 
-import com.genymobile.scrcpy.Ln;
+import com.genymobile.scrcpy.util.Ln;
 
 import android.annotation.SuppressLint;
 import android.graphics.Rect;
@@ -94,6 +94,15 @@ public final class SurfaceControl {
         return getBuiltInDisplayMethod;
     }
 
+    public static boolean hasGetBuildInDisplayMethod() {
+        try {
+            getGetBuiltInDisplayMethod();
+            return true;
+        } catch (NoSuchMethodException e) {
+            return false;
+        }
+    }
+
     public static IBinder getBuiltInDisplay() {
         try {
             Method method = getGetBuiltInDisplayMethod();
@@ -134,7 +143,7 @@ public final class SurfaceControl {
         return getPhysicalDisplayIdsMethod;
     }
 
-    public static boolean hasPhysicalDisplayIdsMethod() {
+    public static boolean hasGetPhysicalDisplayIdsMethod() {
         try {
             getGetPhysicalDisplayIdsMethod();
             return true;
